@@ -21,8 +21,6 @@ import java.util.Timer;
 import java.util.TimerTask;
 import java.util.concurrent.atomic.AtomicReference;
 
-import io.airlift.airline.Command;
-import io.airlift.airline.Option;
 import org.apache.activemq.artemis.api.config.ActiveMQDefaultConfiguration;
 import org.apache.activemq.artemis.api.core.Pair;
 import org.apache.activemq.artemis.cli.Artemis;
@@ -40,15 +38,18 @@ import org.apache.activemq.artemis.dto.ManagementContextDTO;
 import org.apache.activemq.artemis.integration.Broker;
 import org.apache.activemq.artemis.integration.bootstrap.ActiveMQBootstrapLogger;
 import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManager;
+import org.apache.activemq.artemis.utils.ClassloadingUtil;
 import org.apache.activemq.artemis.utils.ReusableLatch;
+import picocli.CommandLine.Command;
+import picocli.CommandLine.Option;
 
 @Command(name = "run", description = "Run the broker.")
 public class Run extends LockAbstract {
 
-   @Option(name = "--allow-kill", description = "This will allow the server to kill itself. Useful for tests (e.g. failover tests).")
+   @Option(names = "--allow-kill", description = "This will allow the server to kill itself. Useful for tests (e.g. failover tests).")
    boolean allowKill;
 
-   @Option(name = "--properties", description = "URL to a properties file that is applied to the server's configuration.")
+   @Option(names = "--properties", description = "URL to a properties file that is applied to the server's configuration.")
    String properties;
 
    private static boolean embedded = false;
@@ -69,6 +70,10 @@ public class Run extends LockAbstract {
       Run.embedded = true;
    }
 
+   public static boolean getEmbedded() {
+      return Run.embedded;
+   }
+
    private Broker server;
 
    @Override
@@ -138,8 +143,7 @@ public class Run extends LockAbstract {
             "system-" + systemWebPropertyPrefix, System.getProperties(), systemWebPropertyPrefix);
 
          for (ComponentDTO componentDTO : broker.components) {
-            Class clazz = this.getClass().getClassLoader().loadClass(componentDTO.componentClassName);
-            ExternalComponent component = (ExternalComponent) clazz.getDeclaredConstructor(null).newInstance();
+            ExternalComponent component = (ExternalComponent) ClassloadingUtil.getInstanceWithTypeCheck(componentDTO.componentClassName, ExternalComponent.class, this.getClass().getClassLoader());
             component.configure(componentDTO, getBrokerInstance(), getBrokerHome());
             server.getServer().addExternalComponent(component, true);
             assert component.isStarted();
@@ -185,7 +189,7 @@ public class Run extends LockAbstract {
          public void run() {
             if (allowKill && fileKill.exists()) {
                try {
-                  System.err.println("Halting by user request");
+                  getActionContext().err.println("Halting by user request");
                   fileKill.delete();
                } catch (Throwable ignored) {
                }
@@ -233,15 +237,15 @@ public class Run extends LockAbstract {
    }
 
 
-   public static void verifyOlderLogging(File etc) throws Exception {
+   public void verifyOlderLogging(File etc) {
       File newLogging = new File(etc, Create.ETC_LOG4J2_PROPERTIES);
       File oldLogging = new File(etc, Upgrade.OLD_LOGGING_PROPERTIES);
 
       if (oldLogging.exists() && !newLogging.exists()) {
-         System.out.println("******************************************************************************************************************************************************************************");
-         System.out.println("Your system has the older logging file " + Upgrade.OLD_LOGGING_PROPERTIES + ", but not the new " + Create.ETC_LOG4J2_PROPERTIES);
-         System.out.println("It appears you did not complete the migration on this artemis instance properly. Please check all the settings or run the './artemis upgrade' command from the new artemis home");
-         System.out.println("******************************************************************************************************************************************************************************");
+         getActionContext().out.println("******************************************************************************************************************************************************************************");
+         getActionContext().out.println("Your system has the older logging file " + Upgrade.OLD_LOGGING_PROPERTIES + ", but not the new " + Create.ETC_LOG4J2_PROPERTIES);
+         getActionContext().out.println("It appears you did not complete the migration on this artemis instance properly. Please check all the settings or run the './artemis upgrade' command from the new artemis home");
+         getActionContext().out.println("******************************************************************************************************************************************************************************");
       }
    }
 
