@@ -18,6 +18,7 @@
 package org.apache.activemq.artemis.protocol.amqp.connect.federation;
 
 import static org.apache.activemq.artemis.protocol.amqp.connect.federation.AMQPFederationConstants.FEDERATION_CONTROL_LINK;
+import static org.apache.activemq.artemis.protocol.amqp.connect.federation.AMQPFederationConstants.FEDERATION_EVENT_LINK;
 import static org.apache.activemq.artemis.protocol.amqp.connect.federation.AMQPFederationConstants.FEDERATION_CONFIGURATION;
 import static org.apache.activemq.artemis.protocol.amqp.proton.AmqpSupport.AMQP_LINK_INITIALIZER_KEY;
 
@@ -26,6 +27,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.UUID;
 import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
@@ -44,7 +46,6 @@ import org.apache.activemq.artemis.protocol.amqp.proton.AMQPConnectionContext;
 import org.apache.activemq.artemis.protocol.amqp.proton.AMQPSessionContext;
 import org.apache.activemq.artemis.protocol.amqp.proton.AmqpSupport;
 import org.apache.activemq.artemis.protocol.amqp.proton.ProtonServerSenderContext;
-import org.apache.activemq.artemis.utils.UUIDGenerator;
 import org.apache.qpid.proton.amqp.Symbol;
 import org.apache.qpid.proton.amqp.messaging.DeleteOnClose;
 import org.apache.qpid.proton.amqp.messaging.Source;
@@ -54,7 +55,7 @@ import org.apache.qpid.proton.amqp.messaging.TerminusExpiryPolicy;
 import org.apache.qpid.proton.amqp.transport.ReceiverSettleMode;
 import org.apache.qpid.proton.amqp.transport.SenderSettleMode;
 import org.apache.qpid.proton.engine.Connection;
-import org.apache.qpid.proton.engine.Link;
+import org.apache.qpid.proton.engine.Receiver;
 import org.apache.qpid.proton.engine.Sender;
 import org.apache.qpid.proton.engine.Session;
 import org.slf4j.Logger;
@@ -77,6 +78,9 @@ public class AMQPFederationSource extends AMQPFederation {
    // the remote federation target.
    private static final Symbol[] CONTROL_LINK_CAPABILITIES = new Symbol[] {FEDERATION_CONTROL_LINK};
 
+   // Capabilities set on the events links used to react to federation resources updates
+   private static final Symbol[] EVENT_LINK_CAPABILITIES = new Symbol[] {FEDERATION_EVENT_LINK};
+
    private final AMQPBrokerConnection brokerConnection;
 
    // Remote policies that should be conveyed to the remote server for reciprocal federation operations.
@@ -100,7 +104,7 @@ public class AMQPFederationSource extends AMQPFederation {
     */
    @SuppressWarnings("unchecked")
    public AMQPFederationSource(String name, Map<String, Object> properties, AMQPBrokerConnection connection) {
-      super(name, connection.getServer());
+      super(connection.getName(), name, connection.getServer());
 
       if (properties == null || properties.isEmpty()) {
          this.properties = Collections.EMPTY_MAP;
@@ -119,11 +123,6 @@ public class AMQPFederationSource extends AMQPFederation {
       return brokerConnection;
    }
 
-   @Override
-   public int getLinkAttachTimeout() {
-      return configuration.getLinkAttachTimeout();
-   }
-
    @Override
    public synchronized AMQPSessionContext getSessionContext() {
       if (!connected) {
@@ -143,30 +142,12 @@ public class AMQPFederationSource extends AMQPFederation {
    }
 
    @Override
-   public synchronized int getReceiverCredits() {
+   public synchronized AMQPFederationConfiguration getConfiguration() {
       if (!connected) {
-         throw new IllegalStateException("Cannot access connection configuration, federation is not connected");
+         throw new IllegalStateException("Cannot access connection while federation is not connected");
       }
 
-      return configuration.getReceiverCredits();
-   }
-
-   @Override
-   public synchronized int getReceiverCreditsLow() {
-      if (!connected) {
-         throw new IllegalStateException("Cannot access connection configuration, federation is not connected");
-      }
-
-      return configuration.getReceiverCreditsLow();
-   }
-
-   @Override
-   public synchronized int getLargeMessageThreshold() {
-      if (!connected) {
-         throw new IllegalStateException("Cannot access connection configuration, federation is not connected");
-      }
-
-      return configuration.getLargeMessageThreshold();
+      return configuration;
    }
 
    /**
@@ -226,6 +207,22 @@ public class AMQPFederationSource extends AMQPFederation {
          }
       });
 
+      try {
+         eventDispatcher.close();
+      } catch (Exception ex) {
+         errorCaught.compareAndExchange(null, ex);
+      } finally {
+         eventDispatcher = null;
+      }
+
+      try {
+         eventProcessor.close(null);
+      } catch (Exception ex) {
+         errorCaught.compareAndExchange(null, ex);
+      } finally {
+         eventProcessor = null;
+      }
+
       connection = null;
       session = null;
 
@@ -271,6 +268,54 @@ public class AMQPFederationSource extends AMQPFederation {
       asyncCreateControlLink();
    }
 
+   @Override
+   protected void handleFederationStarted() throws ActiveMQException {
+      // These should move to the policy manager themselves eventually once
+      // a better lifetime management is worked out for these, right now the
+      // managers are started and stopped on connect and disconnect
+      addressMatchPolicies.forEach((nname, policy) -> {
+         try {
+            registerAddressPolicyManagement(policy);
+         } catch (Exception e) {
+            logger.warn("Error while attempting to add address policy control to management", e);
+         }
+      });
+
+      queueMatchPolicies.forEach((nname, policy) -> {
+         try {
+            registerQueuePolicyManagement(policy);
+         } catch (Exception e) {
+            logger.warn("Error while attempting to add queue policy control to management", e);
+         }
+      });
+
+      super.handleFederationStarted();
+   }
+
+   @Override
+   protected void handleFederationStopped() throws ActiveMQException {
+      // These should move to the policy manager themselves eventually once
+      // a better lifetime management is worked out for these, right now the
+      // managers are started and stopped on connect and disconnect
+      addressMatchPolicies.forEach((nname, policy) -> {
+         try {
+            unregisterAddressPolicyManagement(policy);
+         } catch (Exception e) {
+            logger.warn("Error while attempting to remote address policy control to management", e);
+         }
+      });
+
+      queueMatchPolicies.forEach((nname, policy) -> {
+         try {
+            unregisterQueuePolicyManagement(policy);
+         } catch (Exception e) {
+            logger.warn("Error while attempting to remote queue policy control to management", e);
+         }
+      });
+
+      super.handleFederationStopped();
+   }
+
    @Override
    protected void signalResourceCreateError(Exception cause) {
       brokerConnection.connectError(cause);
@@ -281,8 +326,223 @@ public class AMQPFederationSource extends AMQPFederation {
       brokerConnection.runtimeError(cause);
    }
 
-   protected boolean interceptLinkClosedEvent(Link link) {
-      return false;
+   private void asyncCreateTargetEventsSender(AMQPFederationCommandDispatcher commandLink) {
+      // If no remote policies configured then we don't need an events sender link
+      // currently, if some other use is added for this link this code must be
+      // removed and tests updated to expect this link to always be created.
+      if (remoteAddressMatchPolicies.isEmpty() && remoteQueueMatchPolicies.isEmpty()) {
+         return;
+      }
+
+      // Schedule the outgoing event link creation on the connection event loop thread.
+      //
+      // Eventual establishment of the outgoing events link or refusal informs this side
+      // of the connection as to whether the remote side supports receiving events for
+      // resources that it attempted to federate but they did not exist at the time and
+      // were subsequently added or for resources that might have been later removed via
+      // management and then subsequently re-added.
+      //
+      // Once the outcome of the event link is known then send any remote address or queue
+      // federation policies so that the remote can start federation of local addresses or
+      // queues to itself. This ordering prevents a race on creation of the events link
+      // and any federation consumer creation from the remote.
+      connection.runLater(() -> {
+         if (!isStarted()) {
+            return;
+         }
+
+         try {
+            final Sender sender = session.getSession().sender(
+               "federation-events-sender:" + getName() + ":" + server.getNodeID() + ":" + UUID.randomUUID());
+            final Target target = new Target();
+            final Source source = new Source();
+
+            target.setDynamic(true);
+            target.setCapabilities(new Symbol[] {AmqpSupport.TEMP_TOPIC_CAPABILITY});
+            target.setDurable(TerminusDurability.NONE);
+            target.setExpiryPolicy(TerminusExpiryPolicy.LINK_DETACH);
+            // Set the dynamic node lifetime-policy to indicate this needs to be destroyed on close
+            // we don't want event links nodes remaining once a federation connection is closed.
+            final Map<Symbol, Object> dynamicNodeProperties = new HashMap<>();
+            dynamicNodeProperties.put(AmqpSupport.LIFETIME_POLICY, DeleteOnClose.getInstance());
+            target.setDynamicNodeProperties(dynamicNodeProperties);
+
+            sender.setSenderSettleMode(SenderSettleMode.SETTLED);
+            sender.setReceiverSettleMode(ReceiverSettleMode.FIRST);
+            sender.setDesiredCapabilities(EVENT_LINK_CAPABILITIES);
+            sender.setTarget(target);
+            sender.setSource(source);
+            sender.open();
+
+            final ScheduledFuture<?> futureTimeout;
+            final AtomicBoolean cancelled = new AtomicBoolean(false);
+
+            if (brokerConnection.getConnectionTimeout() > 0) {
+               futureTimeout = brokerConnection.getServer().getScheduledPool().schedule(() -> {
+                  cancelled.set(true);
+                  brokerConnection.connectError(ActiveMQAMQPProtocolMessageBundle.BUNDLE.brokerConnectionTimeout());
+               }, brokerConnection.getConnectionTimeout(), TimeUnit.MILLISECONDS);
+            } else {
+               futureTimeout = null;
+            }
+
+            // Using attachments to set up a Runnable that will be executed inside the remote link opened handler
+            sender.attachments().set(AMQP_LINK_INITIALIZER_KEY, Runnable.class, () -> {
+               try {
+                  if (cancelled.get()) {
+                     return;
+                  }
+
+                  if (futureTimeout != null) {
+                     futureTimeout.cancel(false);
+                  }
+
+                  if (sender.getRemoteTarget() == null || !AmqpSupport.verifyOfferedCapabilities(sender)) {
+                     // Sender rejected or not an event link endpoint so close as we will
+                     // not support sending events to the remote but otherwise will operate
+                     // as normal.
+                     sender.close();
+                  } else {
+                     session.addFederationEventDispatcher(sender);
+                  }
+
+                  // Once we know whether the events support is active or not we can send
+                  // the remote federation policies and allow the remote federation links
+                  // to start forming.
+
+                  remoteQueueMatchPolicies.forEach((key, policy) -> {
+                     try {
+                        commandLink.sendPolicy(policy);
+                     } catch (Exception e) {
+                        brokerConnection.error(e);
+                     }
+                  });
+
+                  remoteAddressMatchPolicies.forEach((key, policy) -> {
+                     try {
+                        commandLink.sendPolicy(policy);
+                     } catch (Exception e) {
+                        brokerConnection.error(e);
+                     }
+                  });
+
+               } catch (Exception e) {
+                  brokerConnection.error(e);
+               }
+            });
+         } catch (Exception e) {
+            brokerConnection.error(e);
+         }
+
+         connection.flush();
+      });
+   }
+
+   private void asnycCreateTargetEventsReceiver() {
+      // If no local policies configured then we don't need an events receiver link
+      // currently, if some other use is added for this link this code must be
+      // removed and tests updated to expect this link to always be created.
+      if (addressMatchPolicies.isEmpty() && queueMatchPolicies.isEmpty()) {
+         return;
+      }
+
+      // Schedule the incoming event link creation on the connection event loop thread.
+      //
+      // Eventual establishment of the incoming event link or refusal informs this side
+      // of the connection as to whether the remote will send events for addresses or
+      // queues that were not present when a federation consumer attempt had failed and
+      // were later added or an existing federation consumer was closed due to management
+      // action and those resource are once again available for federation.
+      //
+      // Once the outcome of the event link is known then start all the policy managers
+      // which will start federation from remote addresses and queues to this broker.
+      // This ordering prevents any races around the events receiver creation and creation
+      // of federation consumers on the remote.
+      connection.runLater(() -> {
+         if (!isStarted()) {
+            return;
+         }
+
+         try {
+            final Receiver receiver = session.getSession().receiver(
+               "federation-events-receiver:" + getName() + ":" + server.getNodeID() + ":" + UUID.randomUUID());
+
+            final Target target = new Target();
+            final Source source = new Source();
+
+            source.setDynamic(true);
+            source.setCapabilities(new Symbol[] {AmqpSupport.TEMP_TOPIC_CAPABILITY});
+            source.setDurable(TerminusDurability.NONE);
+            source.setExpiryPolicy(TerminusExpiryPolicy.LINK_DETACH);
+            // Set the dynamic node lifetime-policy to indicate this needs to be destroyed on close
+            // we don't want event links nodes remaining once a federation connection is closed.
+            final Map<Symbol, Object> dynamicNodeProperties = new HashMap<>();
+            dynamicNodeProperties.put(AmqpSupport.LIFETIME_POLICY, DeleteOnClose.getInstance());
+            source.setDynamicNodeProperties(dynamicNodeProperties);
+
+            receiver.setSenderSettleMode(SenderSettleMode.SETTLED);
+            receiver.setReceiverSettleMode(ReceiverSettleMode.FIRST);
+            receiver.setDesiredCapabilities(EVENT_LINK_CAPABILITIES);
+            receiver.setTarget(target);
+            receiver.setSource(source);
+            receiver.open();
+
+            final ScheduledFuture<?> futureTimeout;
+            final AtomicBoolean cancelled = new AtomicBoolean(false);
+
+            if (brokerConnection.getConnectionTimeout() > 0) {
+               futureTimeout = brokerConnection.getServer().getScheduledPool().schedule(() -> {
+                  cancelled.set(true);
+                  brokerConnection.connectError(ActiveMQAMQPProtocolMessageBundle.BUNDLE.brokerConnectionTimeout());
+               }, brokerConnection.getConnectionTimeout(), TimeUnit.MILLISECONDS);
+            } else {
+               futureTimeout = null;
+            }
+
+            // Using attachments to set up a Runnable that will be executed inside the remote link opened handler
+            receiver.attachments().set(AMQP_LINK_INITIALIZER_KEY, Runnable.class, () -> {
+               try {
+                  if (cancelled.get()) {
+                     return;
+                  }
+
+                  if (futureTimeout != null) {
+                     futureTimeout.cancel(false);
+                  }
+
+                  if (receiver.getRemoteSource() == null || !AmqpSupport.verifyOfferedCapabilities(receiver)) {
+                     // Receiver rejected or not an event link endpoint so close as we will
+                     // not be receiving events from the remote but otherwise will operate
+                     // as normal.
+                     receiver.close();
+                  } else {
+                     session.addFederationEventProcessor(receiver);
+                  }
+
+                  // Once we know whether the events support is active or not we can start the
+                  // local federation policies and allow the outgoing federation links to start
+                  // forming.
+                  //
+                  // Attempt to start the policy managers in another thread to avoid blocking the IO thread
+                  scheduler.execute(() -> {
+                     // Sync action with federation start / stop otherwise we could get out of sync
+                     synchronized (AMQPFederationSource.this) {
+                        if (isStarted()) {
+                           queueMatchPolicies.forEach((k, v) -> v.start());
+                           addressMatchPolicies.forEach((k, v) -> v.start());
+                        }
+                     }
+                  });
+               } catch (Exception e) {
+                  brokerConnection.error(e);
+               }
+            });
+         } catch (Exception e) {
+            brokerConnection.error(e);
+         }
+
+         connection.flush();
+      });
    }
 
    private void asyncCreateControlLink() {
@@ -291,8 +551,8 @@ public class AMQPFederationSource extends AMQPFederation {
       // to a remote peer that can support AMQP federation requirements.
       connection.runLater(() -> {
          try {
-            final Sender sender = session.getSession().sender("Federation:" + getName() + ":" + UUIDGenerator.getInstance().generateStringUUID());
-            final AMQPFederationCommandDispatcher commandLink = new AMQPFederationCommandDispatcher(sender, getServer(), session.getSessionSPI());
+            final Sender sender = session.getSession().sender(
+               "federation-control-link:" + getName() + ":" + server.getNodeID() + ":" + UUID.randomUUID());
             final Target target = new Target();
 
             // The control link should be dynamic and the node is destroyed if the connection drops
@@ -374,6 +634,7 @@ public class AMQPFederationSource extends AMQPFederation {
                      throw new ActiveMQAMQPInternalErrorException("Error while configuring interal session metadata");
                   }
 
+                  final AMQPFederationCommandDispatcher commandLink = new AMQPFederationCommandDispatcher(sender, getServer(), session.getSessionSPI());
                   final ProtonServerSenderContext senderContext =
                      new ProtonServerSenderContext(connection, sender, session, session.getSessionSPI(), commandLink);
 
@@ -381,33 +642,13 @@ public class AMQPFederationSource extends AMQPFederation {
 
                   connected = true;
 
-                  remoteQueueMatchPolicies.forEach((key, policy) -> {
-                     try {
-                        commandLink.sendPolicy(policy);
-                     } catch (Exception e) {
-                        brokerConnection.error(e);
-                     }
-                  });
-
-                  remoteAddressMatchPolicies.forEach((key, policy) -> {
-                     try {
-                        commandLink.sendPolicy(policy);
-                     } catch (Exception e) {
-                        brokerConnection.error(e);
-                     }
-                  });
-
-                  // Attempt to start the policy managers in another thread to avoid blocking the IO thread
-                  scheduler.execute(() -> {
-                     // Sync action with federation start / stop otherwise we could get out of sync
-                     synchronized (AMQPFederationSource.this) {
-                        if (isStarted()) {
-                           queueMatchPolicies.forEach((k, v) -> v.start());
-                           addressMatchPolicies.forEach((k, v) -> v.start());
-                        }
-                     }
-                  });
+                  // Setup events sender link to the target if there are any remote policies and
+                  // then send those polices to start remote federation.
+                  asyncCreateTargetEventsSender(commandLink);
 
+                  // Setup events receiver link from the target if there are any local policies
+                  // and then start the policy managers to begin tracking local demand.
+                  asnycCreateTargetEventsReceiver();
                } catch (Exception e) {
                   brokerConnection.error(e);
                }
