@@ -23,13 +23,13 @@ import org.apache.activemq.artemis.api.config.ActiveMQDefaultConfiguration;
 import org.apache.activemq.artemis.api.core.ActiveMQException;
 import org.apache.activemq.artemis.api.core.ActiveMQExceptionType;
 import org.apache.activemq.artemis.api.core.ActiveMQSecurityException;
+import org.apache.activemq.artemis.api.core.Message;
 import org.apache.activemq.artemis.api.core.RoutingType;
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.core.security.CheckType;
 import org.apache.activemq.artemis.core.server.impl.AddressInfo;
 import org.apache.activemq.artemis.core.settings.impl.AddressFullMessagePolicy;
 import org.apache.activemq.artemis.core.transaction.Transaction;
-import org.apache.activemq.artemis.protocol.amqp.broker.AMQPMessage;
 import org.apache.activemq.artemis.protocol.amqp.broker.AMQPSessionCallback;
 import org.apache.activemq.artemis.protocol.amqp.exceptions.ActiveMQAMQPException;
 import org.apache.activemq.artemis.protocol.amqp.exceptions.ActiveMQAMQPInternalErrorException;
@@ -37,7 +37,9 @@ import org.apache.activemq.artemis.protocol.amqp.exceptions.ActiveMQAMQPNotFound
 import org.apache.activemq.artemis.protocol.amqp.exceptions.ActiveMQAMQPSecurityException;
 import org.apache.activemq.artemis.protocol.amqp.logger.ActiveMQAMQPProtocolLogger;
 import org.apache.activemq.artemis.protocol.amqp.logger.ActiveMQAMQPProtocolMessageBundle;
+import org.apache.activemq.artemis.utils.CompositeAddress;
 import org.apache.qpid.proton.amqp.Symbol;
+import org.apache.qpid.proton.amqp.messaging.DeliveryAnnotations;
 import org.apache.qpid.proton.amqp.messaging.Modified;
 import org.apache.qpid.proton.amqp.messaging.Outcome;
 import org.apache.qpid.proton.amqp.messaging.Rejected;
@@ -92,7 +94,7 @@ public class ProtonServerReceiverContext extends ProtonAbstractReceiver {
          if (target.getDynamic()) {
             // if dynamic we have to create the node (queue) and set the address on the target, the node is temporary and
             // will be deleted on closing of the session
-            address = SimpleString.toSimpleString(sessionSPI.tempQueueName());
+            address = SimpleString.of(sessionSPI.tempQueueName());
             defRoutingType = getRoutingType(target.getCapabilities(), address);
 
             try {
@@ -111,7 +113,7 @@ public class ProtonServerReceiverContext extends ProtonAbstractReceiver {
             // matched on receive of the message.
             String targetAddress = target.getAddress();
             if (targetAddress != null && !targetAddress.isEmpty()) {
-               address = SimpleString.toSimpleString(targetAddress);
+               address = SimpleString.of(targetAddress);
             }
 
             if (address != null) {
@@ -127,8 +129,12 @@ public class ProtonServerReceiverContext extends ProtonAbstractReceiver {
                   throw new ActiveMQAMQPInternalErrorException(e.getMessage(), e);
                }
 
+               final SimpleString addressPart = CompositeAddress.extractAddressName(address);
+               final SimpleString queuePart = CompositeAddress.isFullyQualified(address) ?
+                  CompositeAddress.extractQueueName(address) : null;
+
                try {
-                  sessionSPI.check(address, CheckType.SEND, connection.getSecurityAuth());
+                  sessionSPI.check(addressPart, queuePart, CheckType.SEND, connection.getSecurityAuth());
                } catch (ActiveMQSecurityException e) {
                   throw ActiveMQAMQPProtocolMessageBundle.BUNDLE.securityErrorCreatingProducer(e.getMessage());
                }
@@ -143,6 +149,7 @@ public class ProtonServerReceiverContext extends ProtonAbstractReceiver {
             }
          }
       }
+
       flow();
    }
 
@@ -175,7 +182,7 @@ public class ProtonServerReceiverContext extends ProtonAbstractReceiver {
    }
 
    private RoutingType getDefaultRoutingType(SimpleString address) {
-      RoutingType defaultRoutingType = sessionSPI.getDefaultRoutingType(address);
+      RoutingType defaultRoutingType = sessionSPI.getRoutingTypeFromPrefix(address, sessionSPI.getDefaultRoutingType(address));
       return defaultRoutingType == null ? ActiveMQDefaultConfiguration.getDefaultRoutingType() : defaultRoutingType;
    }
 
@@ -193,7 +200,7 @@ public class ProtonServerReceiverContext extends ProtonAbstractReceiver {
    }
 
    @Override
-   protected void actualDelivery(AMQPMessage message, Delivery delivery, Receiver receiver, Transaction tx) {
+   protected void actualDelivery(Message message, Delivery delivery, DeliveryAnnotations deliveryAnnotations, Receiver receiver, Transaction tx) {
       try {
          if (sessionSPI != null) {
             // message could be null on unit tests (Mocking from ProtonServerReceiverContextTest).
@@ -209,7 +216,7 @@ public class ProtonServerReceiverContext extends ProtonAbstractReceiver {
       }
    }
 
-   private void validateAddressOnAnonymousLink(AMQPMessage message) throws Exception {
+   private void validateAddressOnAnonymousLink(Message message) throws Exception {
       SimpleString newAddress = message.getAddressSimpleString();
       if (newAddress != null && !newAddress.equals(lastAddress)) {
          AddressFullMessagePolicy currentPolicy = sessionSPI.getProtocolManager().getServer().getPagingManager().getPageStore(newAddress).getAddressFullMessagePolicy();
@@ -288,7 +295,7 @@ public class ProtonServerReceiverContext extends ProtonAbstractReceiver {
       org.apache.qpid.proton.amqp.messaging.Target target = (org.apache.qpid.proton.amqp.messaging.Target) receiver.getRemoteTarget();
       if (target != null && target.getDynamic() && (target.getExpiryPolicy() == TerminusExpiryPolicy.LINK_DETACH || target.getExpiryPolicy() == TerminusExpiryPolicy.SESSION_END)) {
          try {
-            sessionSPI.removeTemporaryQueue(SimpleString.toSimpleString(target.getAddress()));
+            sessionSPI.removeTemporaryQueue(SimpleString.of(target.getAddress()));
          } catch (Exception e) {
             //ignore on close, its temp anyway and will be removed later
          }
