@@ -353,13 +353,9 @@ public final class PageSubscriptionImpl implements PageSubscription {
 
             @Override
             public void afterCommit(final Transaction tx1) {
-               pageStore.execute(new Runnable() {
-
-                  @Override
-                  public void run() {
-                     if (!completeDelete) {
-                        cursorProvider.scheduleCleanup();
-                     }
+               pageStore.execute(() -> {
+                  if (!completeDelete) {
+                     cursorProvider.scheduleCleanup();
                   }
                });
             }
@@ -1456,6 +1452,11 @@ public final class PageSubscriptionImpl implements PageSubscription {
 
       @Override
       public void remove() {
+         removeLastElement();
+      }
+
+      @Override
+      public PagedReference removeLastElement() {
          PagedReference delivery = currentDelivery;
          if (delivery != null) {
             PageCursorInfo info = PageSubscriptionImpl.this.getPageInfo(delivery.getPagedMessage().getPageNumber());
@@ -1463,6 +1464,7 @@ public final class PageSubscriptionImpl implements PageSubscription {
                info.remove(delivery.getPagedMessage().getMessageNumber());
             }
          }
+         return delivery;
       }
 
       @Override
