@@ -430,12 +430,14 @@ public class FileConfigurationTest extends AbstractConfigurationTestBase {
             assertEquals("dg1", bc.getDiscoveryGroupName());
             assertEquals(568320, bc.getProducerWindowSize());
             assertEquals(ComponentConfigurationRoutingType.PASS, bc.getRoutingType());
+            assertNull(bc.getClientId());
          } else if (bc.getName().equals("bridge3")) {
             assertEquals("bridge3", bc.getName());
             assertEquals("org.foo.BridgeTransformer3", bc.getTransformerConfiguration().getClassName());
             assertEquals("bridgeTransformerValue1", bc.getTransformerConfiguration().getProperties().get("bridgeTransformerKey1"));
             assertEquals("bridgeTransformerValue2", bc.getTransformerConfiguration().getProperties().get("bridgeTransformerKey2"));
             assertEquals(123456, bc.getPendingAckTimeout());
+            assertEquals("myClientID", bc.getClientId());
          }
       }
 
@@ -454,6 +456,7 @@ public class FileConfigurationTest extends AbstractConfigurationTestBase {
             assertEquals(MessageLoadBalancingType.OFF_WITH_REDISTRIBUTION, ccc.getMessageLoadBalancingType());
             assertEquals(ActiveMQDefaultConfiguration.getDefaultClusterCallTimeout(), ccc.getCallTimeout());
             assertEquals(ActiveMQDefaultConfiguration.getDefaultClusterCallFailoverTimeout(), ccc.getCallFailoverTimeout());
+            assertEquals("myClientID", ccc.getClientId());
          } else if (ccc.getName().equals("cluster-connection1")) {
             assertEquals("cluster-connection1", ccc.getName());
             assertEquals(321, ccc.getMinLargeMessageSize(), "clusterConnectionConf minLargeMessageSize");
@@ -534,6 +537,7 @@ public class FileConfigurationTest extends AbstractConfigurationTestBase {
       assertTrue(conf.getAddressSettings().get("a1").isEnableMetrics());
       assertTrue(conf.getAddressSettings().get("a1").isEnableIngressTimestamp());
       assertNull(conf.getAddressSettings().get("a1").getIDCacheSize());
+      assertNull(conf.getAddressSettings().get("a1").getInitialQueueBufferSize());
 
       assertEquals("a2.1", conf.getAddressSettings().get("a2").getDeadLetterAddress().toString());
       assertTrue(conf.getAddressSettings().get("a2").isAutoCreateDeadLetterResources());
@@ -575,14 +579,18 @@ public class FileConfigurationTest extends AbstractConfigurationTestBase {
       assertFalse(conf.getAddressSettings().get("a2").isEnableMetrics());
       assertFalse(conf.getAddressSettings().get("a2").isEnableIngressTimestamp());
       assertEquals(Integer.valueOf(500), conf.getAddressSettings().get("a2").getIDCacheSize());
+      assertEquals(Integer.valueOf(128), conf.getAddressSettings().get("a2").getInitialQueueBufferSize());
 
       assertEquals(111, conf.getMirrorAckManagerQueueAttempts());
+      assertTrue(conf.isMirrorAckManagerWarnUnacked());
       assertEquals(222, conf.getMirrorAckManagerPageAttempts());
       assertEquals(333, conf.getMirrorAckManagerRetryDelay());
       assertTrue(conf.isMirrorPageTransaction());
 
       assertTrue(conf.getResourceLimitSettings().containsKey("myUser"));
+      // continue testing deprecated method
       assertEquals(104, conf.getResourceLimitSettings().get("myUser").getMaxConnections());
+      assertEquals(104, conf.getResourceLimitSettings().get("myUser").getMaxSessions());
       assertEquals(13, conf.getResourceLimitSettings().get("myUser").getMaxQueues());
 
       assertEquals(2, conf.getQueueConfigs().size());
