@@ -1387,11 +1387,6 @@ public class ScheduledDeliveryHandlerTest {
          return null;
       }
 
-      @Override
-      public MessageReference getReference(long id) {
-         return null;
-      }
-
       @Override
       public int deleteAllReferences() throws Exception {
          return 0;
@@ -1491,6 +1486,11 @@ public class ScheduledDeliveryHandlerTest {
          return 0;
       }
 
+      @Override
+      public boolean copyReference(long messageID, SimpleString address, Binding binding) throws Exception {
+         return false;
+      }
+
       @Override
       public void addRedistributor(long delay) {
 
@@ -1717,5 +1717,10 @@ public class ScheduledDeliveryHandlerTest {
       public void setExclusive(boolean exclusive) {
 
       }
+
+      @Override
+      public int getInitialQueueBufferSize() {
+         return 0;
+      }
    }
 }
