@@ -16,12 +16,6 @@
  */
 package org.apache.activemq.cli.test;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
 import javax.net.ssl.HostnameVerifier;
 import javax.net.ssl.SNIHostName;
 import javax.net.ssl.SSLContext;
@@ -101,15 +95,21 @@ import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.impl.conn.DefaultRoutePlanner;
 import org.apache.http.protocol.HttpContext;
 import org.apache.http.ssl.SSLContextBuilder;
+import org.eclipse.jetty.ee8.webapp.WebAppContext;
+import org.eclipse.jetty.ee8.webapp.WebInfConfiguration;
 import org.eclipse.jetty.util.ssl.SslContextFactory;
 import org.eclipse.jetty.util.thread.ThreadPool;
-import org.eclipse.jetty.webapp.WebAppContext;
-import org.eclipse.jetty.webapp.WebInfConfiguration;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 public class WebServerComponentTest extends ArtemisTestCase {
 
    @TempDir
@@ -164,7 +164,7 @@ public class WebServerComponentTest extends ArtemisTestCase {
       }
       WebServerComponent webServerComponent = new WebServerComponent();
       assertFalse(webServerComponent.isStarted());
-      webServerComponent.configure(webServerDTO, "./src/test/resources/", "./src/test/resources/");
+      webServerComponent.configure(webServerDTO, "src/test/resources/", "src/test/resources/");
       testedComponents.add(webServerComponent);
       webServerComponent.start();
       final int port = webServerComponent.getPort();
@@ -227,7 +227,7 @@ public class WebServerComponentTest extends ArtemisTestCase {
       webServerDTO.webContentEnabled = true;
       WebServerComponent webServerComponent = new WebServerComponent();
       assertFalse(webServerComponent.isStarted());
-      webServerComponent.configure(webServerDTO, "./src/test/resources/", "./src/test/resources/");
+      webServerComponent.configure(webServerDTO, "src/test/resources/", "src/test/resources/");
       webServerComponent.start();
       // Make the connection attempt.
       verifyConnection(webServerComponent.getPort());
@@ -251,7 +251,7 @@ public class WebServerComponentTest extends ArtemisTestCase {
       webServerDTO.webContentEnabled = true;
       WebServerComponent webServerComponent = new WebServerComponent();
       assertFalse(webServerComponent.isStarted());
-      webServerComponent.configure(webServerDTO, "./src/test/resources/", "./src/test/resources/");
+      webServerComponent.configure(webServerDTO, "src/test/resources/", "src/test/resources/");
       webServerComponent.start();
       // Make the connection attempt.
       verifyConnection(webServerComponent.getPort());
@@ -305,7 +305,7 @@ public class WebServerComponentTest extends ArtemisTestCase {
 
       WebServerComponent webServerComponent = new WebServerComponent();
       assertFalse(webServerComponent.isStarted());
-      webServerComponent.configure(webServerDTO, "./src/test/resources/", "./src/test/resources/");
+      webServerComponent.configure(webServerDTO, "src/test/resources/", "src/test/resources/");
       testedComponents.add(webServerComponent);
       webServerComponent.start();
 
@@ -431,14 +431,36 @@ public class WebServerComponentTest extends ArtemisTestCase {
 
    @Test
    public void testSSLAutoReload() throws Exception {
-      File keyStoreFile = new File(tempFolder, "server-keystore.p12");
+      testSSLAutoReload(false);
+   }
+   @Test
+   public void testSSLAutoReloadWithSymbolicLinks() throws Exception {
+      testSSLAutoReload(true);
+   }
+
+   public void testSSLAutoReload(boolean useSymbolicLinks) throws Exception {
+      File serverFolder = new File(tempFolder, "server");
+      File keyStoreFile = new File(serverFolder, "server-keystore.p12");
+
+      assertTrue(serverFolder.mkdir());
 
       Files.copy(WebServerComponentTest.class.getClassLoader().getResourceAsStream("server-keystore.p12"),
          keyStoreFile.toPath(), StandardCopyOption.REPLACE_EXISTING);
 
+      File storeFolder = new File(tempFolder, "store");
+      assertTrue(storeFolder.mkdir());
+
+      String keyStorePath;
+      if (useSymbolicLinks) {
+         keyStorePath = Files.createSymbolicLink(storeFolder.toPath().resolve(
+             "store-keystore.p12"), keyStoreFile.toPath()).toString();
+      } else {
+         keyStorePath = keyStoreFile.getAbsolutePath();
+      }
+
       BindingDTO bindingDTO = new BindingDTO();
       bindingDTO.setSslAutoReload(true);
-      bindingDTO.setKeyStorePath(keyStoreFile.getAbsolutePath());
+      bindingDTO.setKeyStorePath(keyStorePath);
       bindingDTO.setKeyStorePassword(KEY_STORE_PASSWORD);
       WebServerComponent webServerComponent = startSimpleSecureServer(bindingDTO);
 
@@ -476,9 +498,21 @@ public class WebServerComponentTest extends ArtemisTestCase {
 
    @Test
    public void testSSLAutoReloadPemConfigSources() throws Exception {
-      File serverKeyFile = new File(tempFolder, "server-key.pem");
-      File serverCertFile = new File(tempFolder, "server-cert.pem");
-      File serverPemConfigFile = new File(tempFolder, "server-pem-config.properties");
+      testSSLAutoReloadPemConfigSources(false);
+   }
+
+   @Test
+   public void testSSLAutoReloadPemConfigSourcesWithSymbolicLinks() throws Exception {
+      testSSLAutoReloadPemConfigSources(true);
+   }
+
+   private void testSSLAutoReloadPemConfigSources(boolean useSymbolicLinks) throws Exception {
+      File serverFolder = new File(tempFolder, "server");
+      File serverKeyFile = new File(serverFolder, "server-key.pem");
+      File serverCertFile = new File(serverFolder, "server-cert.pem");
+      File serverPemConfigFile = new File(serverFolder, "server-pem-config.properties");
+
+      assertTrue(serverFolder.mkdir());
 
       Files.copy(WebServerComponentTest.class.getClassLoader().getResourceAsStream("server-key.pem"),
          serverKeyFile.toPath(), StandardCopyOption.REPLACE_EXISTING);
@@ -486,14 +520,37 @@ public class WebServerComponentTest extends ArtemisTestCase {
       Files.copy(WebServerComponentTest.class.getClassLoader().getResourceAsStream("server-cert.pem"),
          serverCertFile.toPath(), StandardCopyOption.REPLACE_EXISTING);
 
+      File storeFolder = new File(tempFolder, "store");
+      assertTrue(storeFolder.mkdir());
+
+      String sourceKey;
+      String sourceCert;
+      if (useSymbolicLinks) {
+         sourceKey = Files.createSymbolicLink(storeFolder.toPath().resolve(
+             "store-key.pem"), serverKeyFile.toPath()).toString();
+         sourceCert = Files.createSymbolicLink(storeFolder.toPath().resolve(
+             "store-cert.pem"), serverCertFile.toPath()).toString();
+      } else {
+         sourceKey = serverKeyFile.getAbsolutePath();
+         sourceCert = serverCertFile.getAbsolutePath();
+      }
+
       Files.write(serverPemConfigFile.toPath(), Arrays.asList(new String[]{
-         "source.key=" + serverKeyFile.getAbsolutePath(),
-         "source.cert=" + serverCertFile.getAbsolutePath()
+         "source.key=" + sourceKey,
+         "source.cert=" + sourceCert
       }));
 
+      String keyStorePath;
+      if (useSymbolicLinks) {
+         keyStorePath = Files.createSymbolicLink(storeFolder.toPath().resolve(
+             "store-pem-config.properties"), serverPemConfigFile.toPath()).toString();
+      } else {
+         keyStorePath = serverPemConfigFile.getAbsolutePath();
+      }
+
       BindingDTO bindingDTO = new BindingDTO();
       bindingDTO.setSslAutoReload(true);
-      bindingDTO.setKeyStorePath(serverPemConfigFile.getAbsolutePath());
+      bindingDTO.setKeyStorePath(keyStorePath);
       bindingDTO.setKeyStoreType(PemConfigUtil.PEMCFG_STORE_TYPE);
 
       WebServerComponent webServerComponent = startSimpleSecureServer(bindingDTO);
@@ -603,7 +660,7 @@ public class WebServerComponentTest extends ArtemisTestCase {
 
       WebServerComponent webServerComponent = new WebServerComponent();
       assertFalse(webServerComponent.isStarted());
-      webServerComponent.configure(webServerDTO, "./src/test/resources/", "./src/test/resources/");
+      webServerComponent.configure(webServerDTO, "src/test/resources/", "src/test/resources/");
       testedComponents.add(webServerComponent);
       webServerComponent.start();
       final int port = webServerComponent.getPort();
@@ -703,7 +760,7 @@ public class WebServerComponentTest extends ArtemisTestCase {
    }
 
    @Test
-   public void testServerCleanupBeforeStart() throws Exception {
+   public void testWebServerCleanupAfterStop() throws Exception {
       final String warName = "simple-app.war";
       createTestWar(warName);
       final String url = "simple-app/";
@@ -718,30 +775,44 @@ public class WebServerComponentTest extends ArtemisTestCase {
       webServerComponent.getWebContextData().add(new Pair(ctxt, null));
 
       WebInfConfiguration cfg = new WebInfConfiguration();
-      List<File> garbage = new ArrayList<>();
-
       cfg.resolveTempDirectory(ctxt);
 
-      File tmpdir = ctxt.getTempDirectory();
-      File testDir = tmpdir.getParentFile();
-
-      createGarbagesInDir(testDir, garbage);
-
-      assertTrue(garbage.size() > 0);
-
-      for (File file : garbage) {
-         assertTrue(file.exists());
-      }
-
       webServerComponent.start();
-
-      //make sure those garbage are gone
-      for (File file : garbage) {
-         assertFalse(file.exists(), "file exist: " + file.getAbsolutePath());
-      }
       assertTrue(webServerComponent.isStarted());
+      File warTempDir = new File(ctxt.getTempDirectory().getAbsolutePath());
+      assertTrue(warTempDir.exists(), warTempDir + " doesn't exist!");
       webServerComponent.stop(true);
       assertFalse(webServerComponent.isStarted());
+
+      assertFalse(warTempDir.exists(), warTempDir + " exists!");
+   }
+
+   @Test
+   public void testWebServerCleanupBeforeStart() throws Exception {
+      final String warName = "simple-app.war";
+      createTestWar(warName);
+      final String url = "simple-app/";
+
+      WebServerDTO webServerDTO = createDefaultWebServerDTO(warName, url);
+
+      WebServerComponent webServerComponent = new WebServerComponent();
+      assertFalse(webServerComponent.isStarted());
+      testedComponents.add(webServerComponent);
+      webServerComponent.configure(webServerDTO, "./target", "./target");
+      WebAppContext ctxt = WebServerComponentTestAccessor.createWebAppContext(webServerComponent, url, warName, Paths.get(".").resolve("target").toAbsolutePath(), null);
+      webServerComponent.getWebContextData().add(new Pair(ctxt, null));
+
+      if (!Files.exists(Paths.get(ctxt.getTempDirectory().getAbsolutePath()))) {
+         Files.createDirectory(Paths.get(ctxt.getTempDirectory().getAbsolutePath()));
+      }
+      long originalLastModified = Files.getLastModifiedTime(Paths.get(ctxt.getTempDirectory().getAbsolutePath())).toMillis();
+      Thread.sleep(5);
+      webServerComponent.start();
+      assertTrue(webServerComponent.isStarted());
+      assertFalse(originalLastModified == Files.getLastModifiedTime(Paths.get(ctxt.getTempDirectory().getAbsolutePath())).toMillis());
+      webServerComponent.stop(true);
+      assertFalse(webServerComponent.isStarted());
+      assertFalse(Files.exists(Paths.get(ctxt.getTempDirectory().getAbsolutePath())), ctxt.getTempDirectory().getAbsolutePath() + " exists!");
    }
 
    @Test
