@@ -1,12 +1,12 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with
+ * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
+ * the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -590,6 +590,11 @@ public class DestinationProxy implements Destination {
 
    }
 
+   @Override
+   public void messageDispatched(ConnectionContext context, Subscription sub, MessageReference messageReference) {
+      throw new UnsupportedOperationException("Not implemented yet");
+   }
+
    @Override
    public void messageDiscarded(ConnectionContext context, Subscription sub, MessageReference messageReference) {
       throw new UnsupportedOperationException("Not implemented yet");
@@ -657,6 +662,16 @@ public class DestinationProxy implements Destination {
 
    }
 
+   @Override
+   public boolean isSendDuplicateFromStoreToDLQ() {
+      return false;
+   }
+
+   @Override
+   public void setSendDuplicateFromStoreToDLQ(boolean arg) {
+      throw new UnsupportedOperationException("Not implemented yet");
+   }
+
    @Override
    public void start() throws Exception {
       throw new UnsupportedOperationException("Not implemented yet");
@@ -673,4 +688,14 @@ public class DestinationProxy implements Destination {
    public boolean iterate() {
       throw new UnsupportedOperationException("Not implemented yet");
    }
+
+   @Override
+   public boolean isAdvancedNetworkStatisticsEnabled() {
+      return false;
+   }
+
+   @Override
+   public void setAdvancedNetworkStatisticsEnabled(boolean advancedNetworkStatisticsEnabled) {
+      throw new UnsupportedOperationException("Not implemented yet");
+   }
 }
