@@ -17,18 +17,20 @@
 package org.apache.activemq.artemis.tests.integration.journal;
 
 import java.io.File;
-import java.io.FilenameFilter;
+import java.lang.invoke.MethodHandles;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.CyclicBarrier;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
+import java.util.concurrent.locks.LockSupport;
 
 import org.apache.activemq.artemis.api.core.Pair;
 import org.apache.activemq.artemis.core.config.Configuration;
@@ -36,6 +38,8 @@ import org.apache.activemq.artemis.core.io.IOCallback;
 import org.apache.activemq.artemis.core.io.SequentialFile;
 import org.apache.activemq.artemis.core.io.SequentialFileFactory;
 import org.apache.activemq.artemis.core.io.nio.NIOSequentialFileFactory;
+import org.apache.activemq.artemis.core.journal.EncoderPersister;
+import org.apache.activemq.artemis.core.journal.LoaderCallback;
 import org.apache.activemq.artemis.core.journal.PreparedTransactionInfo;
 import org.apache.activemq.artemis.core.journal.RecordInfo;
 import org.apache.activemq.artemis.core.journal.impl.AbstractJournalUpdateTask;
@@ -43,6 +47,7 @@ import org.apache.activemq.artemis.core.journal.impl.JournalCompactor;
 import org.apache.activemq.artemis.core.journal.impl.JournalFile;
 import org.apache.activemq.artemis.core.journal.impl.JournalFileImpl;
 import org.apache.activemq.artemis.core.journal.impl.JournalImpl;
+import org.apache.activemq.artemis.core.journal.impl.dataformat.ByteArrayEncoding;
 import org.apache.activemq.artemis.core.message.impl.CoreMessage;
 import org.apache.activemq.artemis.core.persistence.impl.journal.JournalStorageManager;
 import org.apache.activemq.artemis.core.persistence.impl.journal.OperationContextImpl;
@@ -51,15 +56,27 @@ import org.apache.activemq.artemis.tests.unit.core.journal.impl.fakes.SimpleEnco
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.utils.ActiveMQThreadFactory;
 import org.apache.activemq.artemis.utils.IDGenerator;
-import org.apache.activemq.artemis.utils.OrderedExecutorFactory;
 import org.apache.activemq.artemis.utils.SimpleIDGenerator;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Test;
+import org.apache.activemq.artemis.utils.TokenBucketLimiter;
+import org.apache.activemq.artemis.utils.TokenBucketLimiterImpl;
+import org.apache.activemq.artemis.utils.actors.OrderedExecutorFactory;
+import org.apache.activemq.artemis.utils.critical.EmptyCriticalAnalyzer;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 public class NIOJournalCompactTest extends JournalImplTestBase {
 
-   private static final int NUMBER_OF_RECORDS = 1000;
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
+
+   private static final int NUMBER_OF_RECORDS = 100;
 
    IDGenerator idGenerator = new SimpleIDGenerator(100000);
 
@@ -94,47 +111,34 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
       ArrayList<Pair<String, String>> renamesRead = new ArrayList<>();
 
-      Assert.assertNotNull(JournalCompactor.readControlFile(fileFactory, strDataFiles, strNewFiles, renamesRead));
+      assertNotNull(JournalCompactor.readControlFile(fileFactory, strDataFiles, strNewFiles, renamesRead));
 
-      Assert.assertEquals(dataFiles.size(), strDataFiles.size());
-      Assert.assertEquals(newFiles.size(), strNewFiles.size());
-      Assert.assertEquals(renames.size(), renamesRead.size());
+      assertEquals(dataFiles.size(), strDataFiles.size());
+      assertEquals(newFiles.size(), strNewFiles.size());
+      assertEquals(renames.size(), renamesRead.size());
 
       Iterator<String> iterDataFiles = strDataFiles.iterator();
       for (JournalFile file : dataFiles) {
-         Assert.assertEquals(file.getFile().getFileName(), iterDataFiles.next());
+         assertEquals(file.getFile().getFileName(), iterDataFiles.next());
       }
-      Assert.assertFalse(iterDataFiles.hasNext());
+      assertFalse(iterDataFiles.hasNext());
 
       Iterator<String> iterNewFiles = strNewFiles.iterator();
       for (JournalFile file : newFiles) {
-         Assert.assertEquals(file.getFile().getFileName(), iterNewFiles.next());
+         assertEquals(file.getFile().getFileName(), iterNewFiles.next());
       }
-      Assert.assertFalse(iterNewFiles.hasNext());
+      assertFalse(iterNewFiles.hasNext());
 
       Iterator<Pair<String, String>> iterRename = renames.iterator();
       for (Pair<String, String> rename : renamesRead) {
          Pair<String, String> original = iterRename.next();
-         Assert.assertEquals(original.getA(), rename.getA());
-         Assert.assertEquals(original.getB(), rename.getB());
+         assertEquals(original.getA(), rename.getA());
+         assertEquals(original.getB(), rename.getB());
       }
-      Assert.assertFalse(iterNewFiles.hasNext());
+      assertFalse(iterNewFiles.hasNext());
 
    }
 
-   //   public void testRepeat() throws Exception
-   //   {
-   //      int i = 0 ;
-   //
-   //      while (true)
-   //      {
-   //         System.out.println("#test (" + (i++) + ")");
-   //         testCrashRenamingFiles();
-   //         tearDown();
-   //         setUp();
-   //      }
-   //   }
-
    @Test
    public void testCrashRenamingFiles() throws Exception {
       internalCompactTest(false, false, true, false, false, false, false, false, false, false, true, false, false);
@@ -247,6 +251,208 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
    }
 
+   @Test
+   public void testInvalidDataCompact() throws Exception {
+
+      setup(2, 60 * 1024, false);
+
+      final byte recordType = (byte) 0;
+
+      journal = new JournalImpl(fileSize, minFiles, minFiles, 0, 0, fileFactory, filePrefix, fileExtension, maxAIO);
+
+      AtomicBoolean failed = new AtomicBoolean(false);
+      journal.setCriticalErrorListener((a, b, c) -> {
+         new Exception("failed").printStackTrace();
+         failed.set(true);
+      });
+
+      journal.start();
+
+      journal.loadInternalOnly();
+
+      journal.appendAddRecord(1, recordType, "test".getBytes(), true);
+
+      journal.appendUpdateRecord(1, recordType, "update".getBytes(), true);
+
+      // this is simulating a bug on the journal usage
+      // compacting should just ignore the record
+      journal.appendUpdateRecordTransactional(3, -1, recordType, "upd".getBytes());
+      journal.appendPrepareRecord(3, "data".getBytes(), true);
+
+      journal.appendUpdateRecordTransactional(4, -1, recordType, "upd".getBytes());
+      journal.appendCommitRecord(3, true);
+
+      journal.testCompact();
+      int cnt = loggerHandler.countText("must be");
+      assertTrue(cnt > 0);
+      assertFalse(failed.get());
+
+      journal.testCompact();
+      assertEquals(cnt, loggerHandler.countText("must be")); // the invalid records should be cleared during a compact
+   }
+
+   @Test
+   public void testSimultaneousDeleteUpdate() throws Exception {
+
+      setup(2, 60 * 1024, false);
+
+      ExecutorService executorService = Executors.newFixedThreadPool(3);
+      runAfter(executorService::shutdownNow);
+
+      AtomicBoolean running = new AtomicBoolean(true);
+
+      final byte recordType = (byte) 0;
+
+      journal = new JournalImpl(fileSize, minFiles, minFiles, 0, 0, fileFactory, filePrefix, fileExtension, maxAIO);
+
+      journal.start();
+
+      journal.loadInternalOnly();
+
+      CountDownLatch latchDone = new CountDownLatch(3);
+      AtomicBoolean failed = new AtomicBoolean(false);
+      CyclicBarrier barrier = new CyclicBarrier(3);
+
+      executorService.execute(() -> {
+         int numberCompact = 0;
+         while (running.get()) {
+            try {
+               if (barrier.await(1, TimeUnit.SECONDS) == -1) {
+                  continue;
+               }
+            } catch (Throwable ignored) {
+               continue;
+            }
+            numberCompact++;
+            if (numberCompact % 10 == 0) {
+               logger.debug("Compact {}", numberCompact);
+            }
+            journal.testCompact();
+         }
+         latchDone.countDown();
+      });
+      executorService.execute(() -> {
+         while (running.get()) {
+
+            long tx = idGenerator.generateID();
+            long record = idGenerator.generateID();
+            try {
+               journal.appendAddRecordTransactional(tx, record, recordType, "test".getBytes());
+               journal.appendCommitRecord(tx, false);
+               journal.appendDeleteRecord(record, true);
+
+               try {
+                  journal.appendDeleteRecord(idGenerator.generateID(), false);
+               } catch (Exception ignored) {
+               }
+
+
+               try {
+                  if (barrier.await(1, TimeUnit.SECONDS) == -1) {
+                     continue;
+                  }
+               } catch (Exception ignored) {
+               }
+
+            } catch (Exception e) {
+               logger.warn(e.getMessage(), e);
+               failed.set(true);
+            }
+         }
+         latchDone.countDown();
+      });
+
+      executorService.execute(() -> {
+         while (running.get()) {
+            long tx = idGenerator.generateID();
+            long record = idGenerator.generateID();
+            try {
+               journal.appendAddRecordTransactional(tx, record, recordType, "test".getBytes());
+               journal.appendRollbackRecord(tx, true);
+            } catch (Exception e) {
+               e.printStackTrace();
+               failed.set(true);
+            }
+         }
+         latchDone.countDown();
+      });
+
+
+      long recordId = idGenerator.generateID();
+      for (int i = 0; i < 100; i++) {
+         if (i % 10 == 0) {
+            logger.debug("i = {}",  i);
+         }
+         recordId = idGenerator.generateID();
+         journal.appendAddRecord(recordId, recordType, "test".getBytes(), false);
+         journal.appendUpdateRecord(recordId, recordType, "update".getBytes(), false);
+
+         long tx = idGenerator.generateID();
+         journal.appendUpdateRecordTransactional(tx, recordId, recordType, "test".getBytes());
+         journal.appendRollbackRecord(tx, true);
+
+         journal.appendDeleteRecord(recordId, false);
+         try {
+            barrier.await(1, TimeUnit.SECONDS); // we will wait a little bit, if compacting still busy we carry on...
+         } catch (Throwable ignored) {
+         }
+      }
+
+      journal.appendAddRecord(idGenerator.generateID(), recordType, "test".getBytes(), true);
+
+      running.set(false);
+      assertTrue(latchDone.await(10, TimeUnit.SECONDS));
+
+      recordId = idGenerator.generateID();
+      journal.appendAddRecord(recordId, recordType, "test".getBytes(), true);
+
+      journal.testCompact();
+
+      journal.stop();
+
+      AtomicInteger count = new AtomicInteger(0);
+
+      journal.start();
+
+      journal.load(new LoaderCallback() {
+         @Override
+         public void addPreparedTransaction(PreparedTransactionInfo preparedTransaction) {
+            logger.warn("Not supposed to have prep TX");
+            failed.set(true);
+         }
+
+         @Override
+         public void addRecord(RecordInfo info) {
+            count.incrementAndGet();
+         }
+
+         @Override
+         public void deleteRecord(long id) {
+            logger.warn("Not supposed to delete");
+            failed.set(true);
+         }
+
+         @Override
+         public void updateRecord(RecordInfo info) {
+            logger.warn("Not supposed to update");
+
+         }
+
+         @Override
+         public void failedTransaction(long transactionID, List<RecordInfo> records, List<RecordInfo> recordsToDelete) {
+            logger.warn("Not supposed to failed TX");
+         }
+      });
+
+
+      assertEquals(2, count.get());
+
+      assertFalse(failed.get());
+
+   }
+
+
+
    @Test
    public void testCompactPrepareRestart() throws Exception {
       setup(2, 60 * 1024, false);
@@ -479,7 +685,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
          performNonTransactionalDelete = false;
       }
 
-      setup(2, 60 * 4096, false);
+      setup(2, 60 * 4096, true);
 
       ArrayList<Long> liveIDs = new ArrayList<>();
 
@@ -518,16 +724,22 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
          @Override
          public void onCompactDone() {
             latchDone.countDown();
-            System.out.println("Waiting on Compact");
+            logger.debug("Waiting on Compact");
             try {
                ActiveMQTestBase.waitForLatch(latchWait);
             } catch (InterruptedException e) {
                e.printStackTrace();
             }
-            System.out.println("Done");
+            logger.debug("Done");
          }
       };
 
+      AtomicInteger criticalErrors = new AtomicInteger(0);
+      journal.setCriticalErrorListener((a, b, c) -> {
+         logger.warn("Error", a);
+         criticalErrors.incrementAndGet();
+      });
+
       journal.setAutoReclaim(false);
 
       startJournal();
@@ -557,6 +769,10 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
          }
       }
 
+      for (int i = 0; i < 10; i++) {
+         journal.appendAddEvent(idGenerator.generateID(), (byte) 0, EncoderPersister.getInstance(), new ByteArrayEncoding(new byte[10]), false, null);
+      }
+
       if (pendingTransactions) {
          for (long i = 0; i < 100; i++) {
             long recordID = idGenerator.generateID();
@@ -581,16 +797,13 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
       journal.forceMoveNextFile();
 
-      Thread t = new Thread() {
-         @Override
-         public void run() {
-            try {
-               journal.testCompact();
-            } catch (Exception e) {
-               e.printStackTrace();
-            }
+      Thread t = new Thread(() -> {
+         try {
+            journal.testCompact();
+         } catch (Exception e) {
+            e.printStackTrace();
          }
-      };
+      });
 
       t.start();
 
@@ -635,17 +848,17 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
          int count = 0;
          for (long liveID : liveIDs) {
             if (count++ % 2 == 0) {
-               System.out.println("Deleting no trans " + liveID);
+               logger.debug("Deleting no trans {}", liveID);
                delete(liveID);
             } else {
-               System.out.println("Deleting TX " + liveID);
+               logger.debug("Deleting TX {}", liveID);
                // A Total new transaction (that was created after the compact started) to delete a record that is being
                // compacted
                deleteTx(transactionID, liveID);
                commit(transactionID++);
             }
 
-            System.out.println("Deletes are going into " + ((JournalImpl) journal).getCurrentFile());
+            logger.debug("Deletes are going into {}", ((JournalImpl) journal).getCurrentFile());
          }
       }
 
@@ -728,6 +941,12 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
       startJournal();
       loadAndCheck();
 
+      if (createControlFile) {
+         assertEquals(0, criticalErrors.get());
+      } else {
+         assertEquals(1, criticalErrors.get());
+      }
+
    }
 
    @Test
@@ -774,7 +993,85 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
       journal.testCompact();
 
-      System.out.println("Debug after compact\n" + journal.debug());
+      logger.debug("Debug after compact {}", journal.debug());
+
+      stopJournal();
+      createJournal();
+      startJournal();
+      loadAndCheck();
+   }
+
+   @Test
+   public void testStressAppends() throws Exception {
+      setup(2, 60 * 1024, true);
+
+      final int NUMBER_OF_RECORDS = 200;
+
+      SimpleIDGenerator idGen = new SimpleIDGenerator(1000);
+
+      createJournal();
+      journal.setAutoReclaim(false);
+
+      startJournal();
+      load();
+
+      AtomicBoolean running = new AtomicBoolean(true);
+      Thread t = new Thread(() -> {
+         while (running.get()) {
+            journal.testCompact();
+         }
+      });
+      t.start();
+
+
+      for (int i = 0; i < NUMBER_OF_RECORDS; i++) {
+         long tx = idGen.generateID();
+         addTx(tx, idGen.generateID());
+         LockSupport.parkNanos(1000);
+         commit(tx);
+      }
+
+
+      running.set(false);
+
+      t.join(50000);
+      if (t.isAlive()) {
+         t.interrupt();
+         fail("supposed to join thread");
+      }
+
+      stopJournal();
+      createJournal();
+      startJournal();
+      loadAndCheck();
+   }
+
+   @Test
+   public void testSimpleCommitCompactInBetween() throws Exception {
+      setup(2, 60 * 1024, false);
+
+      final int NUMBER_OF_RECORDS = 1;
+
+      SimpleIDGenerator idGen = new SimpleIDGenerator(1000);
+
+      createJournal();
+      journal.setAutoReclaim(false);
+
+      startJournal();
+      load();
+
+
+      for (int i = 0; i < NUMBER_OF_RECORDS; i++) {
+         long tx = idGen.generateID();
+         addTx(tx, idGen.generateID());
+         journal.testCompact();
+         journal.testCompact();
+         journal.testCompact();
+         journal.testCompact();
+         logger.debug("going to commit");
+         commit(tx);
+      }
+
 
       stopJournal();
       createJournal();
@@ -917,8 +1214,6 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
       journal.testCompact();
 
-      System.out.println("Debug after compact\n" + journal.debug());
-
       stopJournal();
       createJournal();
       startJournal();
@@ -1129,13 +1424,17 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
          }
       }
 
+      for (int i = 0; i < 10; i++) {
+         journal.appendAddEvent(idGenerator.generateID(), (byte) 0, EncoderPersister.getInstance(), new ByteArrayEncoding(new byte[10]), false, null);
+      }
+
       journal.forceMoveNextFile();
 
-      System.out.println("Number of Files: " + journal.getDataFilesCount());
+      logger.debug("Number of Files: {}", journal.getDataFilesCount());
 
-      System.out.println("Before compact ****************************");
-      System.out.println(journal.debug());
-      System.out.println("*****************************************");
+      logger.debug("Before compact ****************************");
+      logger.debug(journal.debug());
+      logger.debug("*****************************************");
 
       journal.testCompact();
 
@@ -1150,6 +1449,73 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
    }
 
+
+   @Test
+   public void testReconfigureJournalSize() throws Exception {
+      setup(2, 30 * 4096, false);
+
+      createJournal();
+      startJournal();
+      load();
+
+      int NUMBER_OF_RECORDS = 1000;
+
+      // add and remove some data to force reclaiming
+      {
+         ArrayList<Long> ids = new ArrayList<>();
+         for (int i = 0; i < NUMBER_OF_RECORDS; i++) {
+            long id = idGenerator.generateID();
+            ids.add(id);
+            add(id);
+            if (i > 0 && i % 100 == 0) {
+               journal.forceMoveNextFile();
+            }
+         }
+
+         journal.forceMoveNextFile();
+
+         journal.checkReclaimStatus();
+      }
+
+      journal.testCompact();
+
+      stopJournal();
+
+      // expanding the size
+      setup(2, 60 * 4096, false);
+      createJournal();
+      startJournal();
+      loadAndCheck();
+
+      // add and remove some data to force reclaiming
+      {
+         ArrayList<Long> ids = new ArrayList<>();
+         for (int i = 0; i < NUMBER_OF_RECORDS; i++) {
+            long id = idGenerator.generateID();
+            ids.add(id);
+            add(id);
+            if (i > 0 && i % 100 == 0) {
+               journal.forceMoveNextFile();
+            }
+         }
+
+         journal.forceMoveNextFile();
+
+         journal.checkReclaimStatus();
+      }
+      stopJournal();
+
+      // shrinking the size
+      setup(2, 15 * 4096, false);
+      createJournal();
+      startJournal();
+      loadAndCheck();
+
+      journal.testCompact();
+
+
+   }
+
    @Test
    public void testLiveSize() throws Exception {
       setup(2, 60 * 1024, true);
@@ -1187,11 +1553,11 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
       JournalFile[] files2 = journal.getDataFiles();
 
-      Assert.assertEquals(files.length, files2.length);
+      assertEquals(files.length, files2.length);
 
       for (int i = 0; i < files.length; i++) {
-         Assert.assertEquals(expectedSizes.get(i).intValue(), files[i].getLiveSize());
-         Assert.assertEquals(expectedSizes.get(i).intValue(), files2[i].getLiveSize());
+         assertEquals(expectedSizes.get(i).intValue(), files[i].getLiveSize());
+         assertEquals(expectedSizes.get(i).intValue(), files2[i].getLiveSize());
       }
 
       for (long id : listToDelete) {
@@ -1203,7 +1569,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
       JournalFile[] files3 = journal.getDataFiles();
 
       for (JournalFile file : files3) {
-         Assert.assertEquals(0, file.getLiveSize());
+         assertEquals(0, file.getLiveSize());
       }
 
       stopJournal();
@@ -1214,7 +1580,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
       files3 = journal.getDataFiles();
 
       for (JournalFile file : files3) {
-         Assert.assertEquals(0, file.getLiveSize());
+         assertEquals(0, file.getLiveSize());
       }
 
    }
@@ -1339,7 +1705,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
       journal.forceMoveNextFile();
 
       startCompact();
-      System.out.println("Committing TX " + tx);
+      logger.debug("Committing TX {}", tx);
       commit(tx);
       finishCompact();
 
@@ -1389,7 +1755,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
       journal.forceMoveNextFile();
 
       startCompact();
-      System.out.println("Committing TX " + tx1);
+      logger.debug("Committing TX {}", tx1);
       rollback(tx0);
       for (int i = 0; i < 10; i++) {
          addTx(tx1, ids[i]);
@@ -1445,7 +1811,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
       journal.forceMoveNextFile();
 
       startCompact();
-      System.out.println("Committing TX " + tx1);
+      logger.debug("Committing TX {}", tx1);
       rollback(tx0);
       for (int i = 0; i < 10; i++) {
          addTx(tx1, ids[i]);
@@ -1576,11 +1942,11 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
       JournalFile[] files2 = journal.getDataFiles();
 
-      Assert.assertEquals(files.length, files2.length);
+      assertEquals(files.length, files2.length);
 
       for (int i = 0; i < files.length; i++) {
-         Assert.assertEquals(expectedSizes.get(i).intValue(), files[i].getLiveSize());
-         Assert.assertEquals(expectedSizes.get(i).intValue(), files2[i].getLiveSize());
+         assertEquals(expectedSizes.get(i).intValue(), files[i].getLiveSize());
+         assertEquals(expectedSizes.get(i).intValue(), files2[i].getLiveSize());
       }
 
       long tx = idGenerator.generateID();
@@ -1594,7 +1960,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
       JournalFile[] files3 = journal.getDataFiles();
 
       for (JournalFile file : files3) {
-         Assert.assertEquals(0, file.getLiveSize());
+         assertEquals(0, file.getLiveSize());
       }
 
       stopJournal();
@@ -1605,7 +1971,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
       files3 = journal.getDataFiles();
 
       for (JournalFile file : files3) {
-         Assert.assertEquals(0, file.getLiveSize());
+         assertEquals(0, file.getLiveSize());
       }
 
    }
@@ -1621,17 +1987,17 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
       final AtomicLong seqGenerator = new AtomicLong(1);
 
-      final ExecutorService executor = Executors.newCachedThreadPool(ActiveMQThreadFactory.defaultThreadFactory());
+      final ExecutorService executor = Executors.newCachedThreadPool(ActiveMQThreadFactory.defaultThreadFactory(getClass().getName()));
 
-      final ExecutorService ioexecutor = Executors.newCachedThreadPool(ActiveMQThreadFactory.defaultThreadFactory());
+      final ExecutorService ioexecutor = Executors.newCachedThreadPool(ActiveMQThreadFactory.defaultThreadFactory(getClass().getName()));
 
       OrderedExecutorFactory factory = new OrderedExecutorFactory(executor);
 
       OrderedExecutorFactory iofactory = new OrderedExecutorFactory(ioexecutor);
 
-      final ExecutorService deleteExecutor = Executors.newCachedThreadPool(ActiveMQThreadFactory.defaultThreadFactory());
+      final ExecutorService deleteExecutor = Executors.newCachedThreadPool(ActiveMQThreadFactory.defaultThreadFactory(getClass().getName()));
 
-      final JournalStorageManager storage = new JournalStorageManager(config, factory, iofactory);
+      final JournalStorageManager storage = new JournalStorageManager(config, EmptyCriticalAnalyzer.getInstance(), factory, iofactory);
 
       storage.start();
 
@@ -1641,84 +2007,81 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
          ((JournalImpl) storage.getMessageJournal()).setAutoReclaim(false);
          final LinkedList<Long> survivingMsgs = new LinkedList<>();
 
-         Runnable producerRunnable = new Runnable() {
-            @Override
-            public void run() {
-               try {
-                  while (running.get()) {
-                     final long[] values = new long[100];
-                     long tx = seqGenerator.incrementAndGet();
+         Runnable producerRunnable = () -> {
+            TokenBucketLimiter limiter = new TokenBucketLimiterImpl(5000, true);
+            try {
+               while (running.get()) {
+                  limiter.limit();
+                  final long[] values = new long[100];
+                  long tx = seqGenerator.incrementAndGet();
 
-                     OperationContextImpl ctx = new OperationContextImpl(executor);
-                     storage.setContext(ctx);
+                  OperationContextImpl ctx = new OperationContextImpl(executor);
+                  storage.setContext(ctx);
 
-                     for (int i = 0; i < 100; i++) {
-                        long id = seqGenerator.incrementAndGet();
-                        values[i] = id;
+                  for (int i = 0; i < 100; i++) {
+                     long id = seqGenerator.incrementAndGet();
+                     values[i] = id;
 
-                        CoreMessage message = new CoreMessage(id, 100);
+                     CoreMessage message = new CoreMessage(id, 100);
 
-                        message.getBodyBuffer().writeBytes(new byte[1024]);
-
-                        storage.storeMessageTransactional(tx, message);
-                     }
-                     CoreMessage message = new CoreMessage(seqGenerator.incrementAndGet(), 100);
-
-                     survivingMsgs.add(message.getMessageID());
-
-                     // This one will stay here forever
-                     storage.storeMessage(message);
-
-                     storage.commit(tx);
-
-                     ctx.executeOnCompletion(new IOCallback() {
-                        @Override
-                        public void onError(int errorCode, String errorMessage) {
-                        }
-
-                        @Override
-                        public void done() {
-                           deleteExecutor.execute(new Runnable() {
-                              @Override
-                              public void run() {
-                                 try {
-                                    for (long messageID : values) {
-                                       storage.deleteMessage(messageID);
-                                    }
-                                 } catch (Throwable e) {
-                                    e.printStackTrace();
-                                    errors.incrementAndGet();
-                                 }
-
-                              }
-                           });
-                        }
-                     });
+                     message.getBodyBuffer().writeBytes(new byte[1024]);
 
+                     storage.storeMessageTransactional(tx, message);
                   }
-               } catch (Throwable e) {
-                  e.printStackTrace();
-                  errors.incrementAndGet();
+                  CoreMessage message = new CoreMessage(seqGenerator.incrementAndGet(), 100);
+
+                  survivingMsgs.add(message.getMessageID());
+
+                  logger.debug("Going to store {}", message);
+                  // This one will stay here forever
+                  storage.storeMessage(message);
+                  logger.debug("message stored {}", message);
+
+                  logger.debug("Going to commit {}", tx);
+                  storage.commit(tx);
+                  logger.debug("Committed {}", tx);
+
+                  ctx.executeOnCompletion(new IOCallback() {
+                     @Override
+                     public void onError(int errorCode, String errorMessage) {
+                     }
+
+                     @Override
+                     public void done() {
+                        deleteExecutor.execute(() -> {
+                           try {
+                              for (long messageID : values) {
+                                 storage.deleteMessage(messageID);
+                              }
+                           } catch (Throwable e) {
+                              e.printStackTrace();
+                              errors.incrementAndGet();
+                           }
+
+                        });
+                     }
+                  });
+
                }
+            } catch (Throwable e) {
+               e.printStackTrace();
+               errors.incrementAndGet();
             }
          };
 
-         Runnable compressRunnable = new Runnable() {
-            @Override
-            public void run() {
-               try {
-                  while (running.get()) {
-                     Thread.sleep(500);
-                     System.out.println("Compacting");
-                     ((JournalImpl) storage.getMessageJournal()).testCompact();
-                     ((JournalImpl) storage.getMessageJournal()).checkReclaimStatus();
-                  }
-               } catch (Throwable e) {
-                  e.printStackTrace();
-                  errors.incrementAndGet();
+         Runnable compressRunnable = () -> {
+            try {
+               while (running.get()) {
+                  Thread.sleep(500);
+                  logger.debug("Compacting");
+                  ((JournalImpl) storage.getMessageJournal()).testCompact();
+                  ((JournalImpl) storage.getMessageJournal()).checkReclaimStatus();
                }
-
+            } catch (Throwable e) {
+               e.printStackTrace();
+               errors.incrementAndGet();
             }
+
          };
 
          Thread producerThread = new Thread(producerRunnable);
@@ -1727,7 +2090,7 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
          Thread compactorThread = new Thread(compressRunnable);
          compactorThread.start();
 
-         Thread.sleep(1000);
+         Thread.sleep(500);
 
          running.set(false);
 
@@ -1737,17 +2100,19 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
          deleteExecutor.shutdown();
 
-         assertTrue("delete executor failted to terminate", deleteExecutor.awaitTermination(30, TimeUnit.SECONDS));
+         assertTrue(deleteExecutor.awaitTermination(30, TimeUnit.SECONDS), "delete executor failted to terminate");
 
          storage.stop();
 
          executor.shutdown();
 
-         assertTrue("executor failed to terminate", executor.awaitTermination(30, TimeUnit.SECONDS));
+         assertTrue(executor.awaitTermination(30, TimeUnit.SECONDS), "executor failed to terminate");
 
          ioexecutor.shutdown();
 
-         assertTrue("ioexecutor failed to terminate", ioexecutor.awaitTermination(30, TimeUnit.SECONDS));
+         assertTrue(ioexecutor.awaitTermination(30, TimeUnit.SECONDS), "ioexecutor failed to terminate");
+
+         assertEquals(0, errors.get());
 
       } catch (Throwable e) {
          e.printStackTrace();
@@ -1766,21 +2131,38 @@ public class NIOJournalCompactTest extends JournalImplTestBase {
 
    }
 
+   @Test
+   public void testLargeCompacting() throws Exception {
+      setup(2, 8 * 1024, false);
+
+      createJournal();
+
+      startJournal();
+
+      load();
+
+
+      for (int i = 0; i < 250; i += 2) {
+         addTx(i, i + 1);
+
+         commit(i);
+
+         journal.forceMoveNextFile();
+      }
+
+      journal.testCompact();
+   }
+
+
    @Override
-   @After
+   @AfterEach
    public void tearDown() throws Exception {
       File testDir = new File(getTestDir());
 
-      File[] files = testDir.listFiles(new FilenameFilter() {
-
-         @Override
-         public boolean accept(File dir, String name) {
-            return name.startsWith(filePrefix) && name.endsWith(fileExtension);
-         }
-      });
+      File[] files = testDir.listFiles((dir, name) -> name.startsWith(filePrefix) && name.endsWith(fileExtension));
 
       for (File file : files) {
-         assertEquals("File " + file + " doesn't have the expected number of bytes", fileSize, file.length());
+         assertEquals(fileSize, file.length(), "File " + file + " doesn't have the expected number of bytes");
       }
 
       super.tearDown();
