@@ -153,20 +153,17 @@ public class MQTTTest extends MQTTTestSupport {
 
       final CountDownLatch latch = new CountDownLatch(NUM_MESSAGES);
 
-      Thread thread = new Thread(new Runnable() {
-         @Override
-         public void run() {
-            for (int i = 0; i < NUM_MESSAGES; i++) {
-               try {
-                  byte[] payload = subscriptionProvider.receive(10000);
-                  assertNotNull(payload, "Should get a message");
-                  latch.countDown();
-               } catch (Exception e) {
-                  e.printStackTrace();
-                  break;
-               }
-
+      Thread thread = new Thread(() -> {
+         for (int i = 0; i < NUM_MESSAGES; i++) {
+            try {
+               byte[] payload = subscriptionProvider.receive(10000);
+               assertNotNull(payload, "Should get a message");
+               latch.countDown();
+            } catch (Exception e) {
+               e.printStackTrace();
+               break;
             }
+
          }
       });
       thread.start();
@@ -270,20 +267,17 @@ public class MQTTTest extends MQTTTestSupport {
 
       final CountDownLatch latch = new CountDownLatch(NUM_MESSAGES / 2);
 
-      Thread thread = new Thread(new Runnable() {
-         @Override
-         public void run() {
-            for (int i = 0; i < NUM_MESSAGES; i++) {
-               try {
-                  byte[] payload = subscriptionProvider.receive(10000);
-                  assertNotNull(payload, "Should get a message");
-                  latch.countDown();
-               } catch (Exception e) {
-                  e.printStackTrace();
-                  break;
-               }
-
+      Thread thread = new Thread(() -> {
+         for (int i = 0; i < NUM_MESSAGES; i++) {
+            try {
+               byte[] payload = subscriptionProvider.receive(10000);
+               assertNotNull(payload, "Should get a message");
+               latch.countDown();
+            } catch (Exception e) {
+               e.printStackTrace();
+               break;
             }
+
          }
       });
       thread.start();
@@ -1170,7 +1164,7 @@ public class MQTTTest extends MQTTTestSupport {
    @Disabled
    @Test
    @Timeout(90)
-   // TODO ActiveMQ 5.x does not reset the message id generator even after a clean session.  In Artemis we always reset.
+   // TODO ActiveMQ Classic does not reset the message id generator even after a clean session.  In Artemis we always reset.
    // If there is a good reason for this we should follow ActiveMQ.
    public void testPacketIdGeneratorCleanSession() throws Exception {
       final String[] cleanClientIds = new String[]{"", "clean-packetid", null};
