@@ -16,6 +16,10 @@
  */
 package org.apache.activemq.artemis.tests.integration.mqtt5.spec;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.List;
@@ -37,7 +41,8 @@ import org.apache.activemq.artemis.tests.util.RandomUtil;
 import org.apache.activemq.artemis.tests.util.Wait;
 import org.eclipse.paho.mqttv5.client.MqttClient;
 import org.eclipse.paho.mqttv5.common.MqttMessage;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 
 /**
  * Fulfilled by client or Netty codec (i.e. not explicitly tested here):
@@ -52,7 +57,8 @@ public class ControlPacketFormatTests extends MQTT5TestSupport {
    /*
     * [MQTT-2.2.1-2] A PUBLISH packet MUST NOT contain a Packet Identifier if its QoS value is set to 0.
     */
-   @Test(timeout = DEFAULT_TIMEOUT)
+   @Test
+   @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testPacketIdQoSZero() throws Exception {
       final String TOPIC = this.getTopicName();
       final String CONSUMER_CLIENT_ID = "consumer";
@@ -89,7 +95,8 @@ public class ControlPacketFormatTests extends MQTT5TestSupport {
     * [MQTT-2.2.1-4] Each time a Server sends a new PUBLISH (with QoS > 0) MQTT Control Packet it MUST assign it a non
     * zero Packet Identifier that is currently unused.
     */
-   @Test(timeout = DEFAULT_TIMEOUT)
+   @Test
+   @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testPacketIdQoSGreaterThanZero() throws Exception {
       final String CONSUMER_ID = RandomUtil.randomString();
       final String TOPIC = this.getTopicName();
@@ -133,7 +140,8 @@ public class ControlPacketFormatTests extends MQTT5TestSupport {
     * [MQTT-2.2.1-5] A PUBACK, PUBREC, PUBREL, or PUBCOMP packet MUST contain the same Packet Identifier as the PUBLISH
     * packet that was originally sent.
     */
-   @Test(timeout = DEFAULT_TIMEOUT)
+   @Test
+   @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testPacketIdPubAckQoS2() throws Exception {
       AtomicInteger id = new AtomicInteger(0);
       AtomicBoolean failed = new AtomicBoolean(false);
@@ -204,7 +212,8 @@ public class ControlPacketFormatTests extends MQTT5TestSupport {
     * [MQTT-2.2.1-5] A PUBACK, PUBREC, PUBREL, or PUBCOMP packet MUST contain the same Packet Identifier as the PUBLISH
     * packet that was originally sent.
     */
-   @Test(timeout = DEFAULT_TIMEOUT)
+   @Test
+   @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testPacketIdPubAckQoS1() throws Exception {
       AtomicInteger id = new AtomicInteger(0);
       AtomicBoolean failed = new AtomicBoolean(false);
@@ -275,7 +284,8 @@ public class ControlPacketFormatTests extends MQTT5TestSupport {
     * [MQTT-2.2.1-6] A SUBACK and UNSUBACK MUST contain the Packet Identifier that was used in the corresponding
     * SUBSCRIBE and UNSUBSCRIBE packet respectively.
     */
-   @Test(timeout = DEFAULT_TIMEOUT)
+   @Test
+   @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testPacketIdSubAckAndUnsubAck() throws Exception {
       AtomicInteger subId = new AtomicInteger(0);
       AtomicInteger unsubId = new AtomicInteger(0);
