@@ -85,7 +85,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       Configuration config = createDefaultInVMConfig().setJournalSyncNonTransactional(false);
 
-      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, -1, -1, new HashMap<String, AddressSettings>());
+      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, -1, -1, new HashMap<>());
 
       server.start();
 
@@ -175,7 +175,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       Configuration config = createDefaultInVMConfig().setJournalSyncNonTransactional(false);
 
-      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, new HashMap<String, AddressSettings>());
+      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, new HashMap<>());
 
       server.start();
 
@@ -206,32 +206,29 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       final AtomicInteger errors = new AtomicInteger(0);
 
-      Thread t1 = new Thread() {
-         @Override
-         public void run() {
-            try {
-               ServerLocator sl = createInVMNonHALocator();
-               ClientSessionFactory sf = sl.createSessionFactory();
-               ClientSession sess = sf.createSession(true, true, 0);
-               sess.start();
-               ClientConsumer cons = sess.createConsumer(ADDRESS);
-               for (int i = 0; i < numberOfMessages; i++) {
-                  ClientMessage msg = cons.receive(5000);
-                  assertNotNull(msg);
-                  assertEquals(i, msg.getIntProperty("id").intValue());
-                  msg.acknowledge();
-               }
-
-               assertNull(cons.receiveImmediate());
-               sess.close();
-               sl.close();
-            } catch (Throwable e) {
-               e.printStackTrace();
-               errors.incrementAndGet();
+      Thread t1 = new Thread(() -> {
+         try {
+            ServerLocator sl = createInVMNonHALocator();
+            ClientSessionFactory sf1 = sl.createSessionFactory();
+            ClientSession sess = sf1.createSession(true, true, 0);
+            sess.start();
+            ClientConsumer cons = sess.createConsumer(ADDRESS);
+            for (int i = 0; i < numberOfMessages; i++) {
+               ClientMessage msg = cons.receive(5000);
+               assertNotNull(msg);
+               assertEquals(i, msg.getIntProperty("id").intValue());
+               msg.acknowledge();
             }
 
+            assertNull(cons.receiveImmediate());
+            sess.close();
+            sl.close();
+         } catch (Throwable e) {
+            e.printStackTrace();
+            errors.incrementAndGet();
          }
-      };
+
+      });
 
       t1.start();
 
@@ -309,7 +306,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       Configuration config = createDefaultInVMConfig().setJournalSyncNonTransactional(false);
 
-      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, new HashMap<String, AddressSettings>());
+      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, new HashMap<>());
 
       server.start();
 
@@ -340,30 +337,27 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       final AtomicInteger errors = new AtomicInteger(0);
 
-      Thread t1 = new Thread() {
-         @Override
-         public void run() {
-            try {
-               ServerLocator sl = createInVMNonHALocator();
-               ClientSessionFactory sf = sl.createSessionFactory();
-               ClientSession sess = sf.createSession(true, true, 0);
-               sess.start();
-               ClientConsumer cons = sess.createConsumer(ADDRESS);
-               for (int i = 0; i < 100; i++) {
-                  ClientMessage msg = cons.receive(5000);
-                  assertNotNull(msg);
-                  assertEquals(i, msg.getIntProperty("id").intValue());
-                  msg.acknowledge();
-               }
-               sess.close();
-               sl.close();
-            } catch (Throwable e) {
-               e.printStackTrace();
-               errors.incrementAndGet();
+      Thread t1 = new Thread(() -> {
+         try {
+            ServerLocator sl = createInVMNonHALocator();
+            ClientSessionFactory sf1 = sl.createSessionFactory();
+            ClientSession sess = sf1.createSession(true, true, 0);
+            sess.start();
+            ClientConsumer cons = sess.createConsumer(ADDRESS);
+            for (int i = 0; i < 100; i++) {
+               ClientMessage msg = cons.receive(5000);
+               assertNotNull(msg);
+               assertEquals(i, msg.getIntProperty("id").intValue());
+               msg.acknowledge();
             }
-
+            sess.close();
+            sl.close();
+         } catch (Throwable e) {
+            e.printStackTrace();
+            errors.incrementAndGet();
          }
-      };
+
+      });
 
       for (int i = 0; i < numberOfMessages; i++) {
          ClientMessage message = session.createMessage(persistentMessages);
@@ -403,7 +397,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       Configuration config = createDefaultInVMConfig().setJournalSyncNonTransactional(false);
 
-      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, -1, -1, new HashMap<String, AddressSettings>());
+      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, -1, -1, new HashMap<>());
 
       server.start();
 
@@ -488,7 +482,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       Configuration config = createDefaultInVMConfig().setJournalSyncNonTransactional(false);
 
-      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, -1, -1, new HashMap<String, AddressSettings>());
+      ActiveMQServer server = createServer(true, config, PAGE_SIZE, PAGE_MAX, -1, -1, new HashMap<>());
 
       server.start();
 
@@ -611,7 +605,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       Configuration config = createDefaultInVMConfig().setJournalSyncNonTransactional(false);
 
-      ActiveMQServer server = createServer(true, config, PAGE_SIZE, -1, new HashMap<String, AddressSettings>());
+      ActiveMQServer server = createServer(true, config, PAGE_SIZE, -1, new HashMap<>());
 
       JMSServerManagerImpl jmsServer = new JMSServerManagerImpl(server);
       InVMNamingContext context = new InVMNamingContext();
@@ -648,7 +642,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       jmsServer.stop();
 
-      server = createServer(true, config, PAGE_SIZE, -1, new HashMap<String, AddressSettings>());
+      server = createServer(true, config, PAGE_SIZE, -1, new HashMap<>());
 
       jmsServer = new JMSServerManagerImpl(server);
       context = new InVMNamingContext();
@@ -674,7 +668,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       Configuration config = createDefaultInVMConfig().setJournalSyncNonTransactional(false);
 
-      ActiveMQServer server = createServer(true, config, -1, -1, new HashMap<String, AddressSettings>());
+      ActiveMQServer server = createServer(true, config, -1, -1, new HashMap<>());
       server.getAddressSettingsRepository().getMatch("#").setAddressFullMessagePolicy(AddressFullMessagePolicy.BLOCK);
 
       JMSServerManagerImpl jmsServer = new JMSServerManagerImpl(server);
@@ -717,7 +711,7 @@ public class PagingOrderTest extends ActiveMQTestBase {
 
       jmsServer.stop();
 
-      server = createServer(true, config, -1, -1, new HashMap<String, AddressSettings>());
+      server = createServer(true, config, -1, -1, new HashMap<>());
       server.getAddressSettingsRepository().getMatch("#").setAddressFullMessagePolicy(AddressFullMessagePolicy.BLOCK);
 
       jmsServer = new JMSServerManagerImpl(server);
